==> open-xchange-admin-contextrestore_7.6.3.orig.tar.bz2: open-xchange-admin-contextrestore-7.6.3/com.openexchange.admin.contextrestore/src/com/openexchange/admin/contextrestore/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.admin.contextrestore.osgi;

import java.rmi.Remote;
import java.util.concurrent.atomic.AtomicReference;
import org.osgi.framework.BundleContext;
import com.openexchange.admin.contextrestore.rmi.impl.OXContextRestore;
import com.openexchange.admin.rmi.OXContextInterface;
import com.openexchange.admin.rmi.exceptions.StorageException;
import com.openexchange.admin.rmi.impl.OXContext;
import com.openexchange.admin.tools.AdminCache;
import com.openexchange.config.ConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link Activator} - The activator for <b><code>com.openexchange.admin.contextrestore</code></b> bundle.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class Activator extends HousekeepingActivator {

    private static final AtomicReference<OXContextInterface> OXContextInterfaceReference = new AtomicReference<OXContextInterface>();

    @Override
    protected void startBundle() throws Exception {
        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(Activator.class);
        try {
            final BundleContext context = this.context;
            AdminCache.compareAndSetBundleContext(null, context);
            final ConfigurationService service = getService(ConfigurationService.class);
            // Parse ConfigDB name from "writeUrl" property in file configdb.properties
            {
                final String jdbcUrl = service.getProperty("writeUrl", "jdbc:mysql://localhost/configdb");
                int pos = jdbcUrl.indexOf("://");
                pos = jdbcUrl.indexOf('/', pos > 0 ? pos + 3 : 0);
                if (pos > 0) {
                    OXContextRestore.setConfigDbName(jdbcUrl.substring(pos + 1));
                }
            }
            // Continue
            AdminCache.compareAndSetConfigurationService(null, service);
            OXContextInterfaceReference.set(new OXContext(context));
            // Register service
            registerService(Remote.class, new OXContextRestore());
            log.info("RMI Interface for context restore registered.");
        } catch (final StorageException e) {
            log.error("Error while creating instance for OXContextRestoreInterface interface", e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        super.stopBundle();
        OXContextInterfaceReference.set(null);
    }

    /**
     * Gets the {@link OXContextInterface} instance.
     *
     * @return The {@link OXContextInterface} instance or <code>null</code>
     */
    public static OXContextInterface getContextInterface() {
        return OXContextInterfaceReference.get();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class };
    }

}

==> open-xchange-admin-contextrestore_7.8.1.orig.tar.bz2: open-xchange-admin-contextrestore-7.8.1/com.openexchange.admin.contextrestore/src/com/openexchange/admin/contextrestore/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.admin.contextrestore.osgi;

import java.rmi.Remote;
import java.util.concurrent.atomic.AtomicReference;
import org.osgi.framework.BundleContext;
import com.openexchange.admin.contextrestore.rmi.impl.OXContextRestore;
import com.openexchange.admin.daemons.AdminDaemonService;
import com.openexchange.admin.rmi.OXContextInterface;
import com.openexchange.admin.rmi.exceptions.StorageException;
import com.openexchange.admin.rmi.impl.OXContext;
import com.openexchange.admin.tools.AdminCache;
import com.openexchange.config.ConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link Activator} - The activator for <b><code>com.openexchange.admin.contextrestore</code></b> bundle.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class Activator extends HousekeepingActivator {

    private static final AtomicReference<OXContextInterface> OXContextInterfaceReference = new AtomicReference<OXContextInterface>();

    @Override
    protected void startBundle() throws Exception {
        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(Activator.class);
        try {
            final BundleContext context = this.context;
            AdminCache.compareAndSetBundleContext(null, context);
            final ConfigurationService service = getService(ConfigurationService.class);
            // Parse ConfigDB name from "writeUrl" property in file configdb.properties
            {
                final String jdbcUrl = service.getProperty("writeUrl", "jdbc:mysql://localhost/configdb");
                int pos = jdbcUrl.indexOf("://");
                pos = jdbcUrl.indexOf('/', pos > 0 ? pos + 3 : 0);
                if (pos > 0) {
                    OXContextRestore.setConfigDbName(jdbcUrl.substring(pos + 1));
                }
            }
            // Continue
            AdminCache.compareAndSetConfigurationService(null, service);
            OXContextInterfaceReference.set(new OXContext(context));
            // Register service
            registerService(Remote.class, new OXContextRestore());
            log.info("RMI Interface for context restore registered.");
        } catch (final StorageException e) {
            log.error("Error while creating instance for OXContextRestoreInterface interface", e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        super.stopBundle();
        OXContextInterfaceReference.set(null);
    }

    /**
     * Gets the {@link OXContextInterface} instance.
     *
     * @return The {@link OXContextInterface} instance or <code>null</code>
     */
    public static OXContextInterface getContextInterface() {
        return OXContextInterfaceReference.get();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class, AdminDaemonService.class };
    }

}
